Configures one provider implementation for a DripDrop channel.
Credentials are encrypted at rest and provider validation is delegated to the registered channel module so built-in and host-registered adapters follow the same contract.
Summary
Functions
Builds a changeset for creating or updating a channel adapter.
Functions
@spec changeset(Ecto.Schema.t(), map()) :: Ecto.Changeset.t()
Builds a changeset for creating or updating a channel adapter.