DripDrop.Migration (DripDrop v0.1.0)

Copy Markdown View Source

Versioned DripDrop schema migrations for host applications.

Summary

Functions

Returns the current migration version supported by this library.

Rolls back migrations to the target version.

Returns the currently migrated version from the database.

Applies migrations up to the target version.

Functions

current_version()

@spec current_version() :: pos_integer()

Returns the current migration version supported by this library.

down(opts \\ [])

@spec down(keyword()) :: :ok

Rolls back migrations to the target version.

Options

  • :prefix - Schema prefix. Defaults to "dripdrop".
  • :version - Target version to roll back to. Defaults to 0.

migrated_version(opts \\ [])

@spec migrated_version(keyword()) :: non_neg_integer()

Returns the currently migrated version from the database.

Returns 0 if no migrations have been applied.

up(opts \\ [])

@spec up(keyword()) :: :ok

Applies migrations up to the target version.

Options

  • :prefix - Schema prefix. Defaults to "dripdrop".
  • :version - Target version. Defaults to 1.