DripDrop.OnReply behaviour (DripDrop v0.1.0)

Copy Markdown View Source

Default reply handler for inbound provider events.

Replies are recorded as message events. A step can additionally set config["reply_behavior"] = "pause_enrollment" to pause the enrollment when a reply is received. Host applications may configure config :dripdrop, :on_reply, {Module, :fun} to replace this behavior.

Summary

Callbacks

Handles an inbound reply event using the configured or default reply callback.

Functions

Handles an inbound reply event using the configured or default reply callback.

Callbacks

handle_reply(map, arg2)

@callback handle_reply(map(), Ecto.Schema.t() | nil) :: :ok | {:error, term()}

Handles an inbound reply event using the configured or default reply callback.

Functions

handle_reply(event, execution)

@spec handle_reply(map(), Ecto.Schema.t() | nil) :: :ok | {:error, term()}

Handles an inbound reply event using the configured or default reply callback.