DripDrop.Policy.UnsubscribeHeaders (DripDrop v0.1.0)

Copy Markdown View Source

Adds RFC 8058 one-click unsubscribe headers when a step opts in.

Summary

Functions

Adds List-Unsubscribe headers to an email payload when the step opts in.

Returns whether an unsubscribe URL builder is configured.

Returns whether unsubscribe headers are enabled for a dispatch context.

Functions

apply(payload, context)

@spec apply(map(), map()) :: {:ok, map()} | {:error, map()}

Adds List-Unsubscribe headers to an email payload when the step opts in.

configured?()

@spec configured?() :: boolean()

Returns whether an unsubscribe URL builder is configured.

enabled?(arg1)

@spec enabled?(map()) :: boolean()

Returns whether unsubscribe headers are enabled for a dispatch context.