DripDrop.ShortLinks.Pipeline (DripDrop v0.1.0)

Copy Markdown View Source

Rewrites payload URLs through the configured short-link provider.

Summary

Functions

Rewrites eligible URLs in a rendered payload through the configured provider.

Types

context()

@type context() :: %{
  optional(:step_execution_id) => Ecto.UUID.t() | binary(),
  optional(:tenant_key) => binary() | nil,
  optional(:sequence) => Ecto.Schema.t() | map(),
  optional(:step) => Ecto.Schema.t() | map(),
  optional(:provider_opts) => keyword(),
  optional(:tenant_short_links) => keyword()
}

Functions

run(payload, context \\ %{})

@spec run(map(), context()) :: {:ok, map()} | {:error, map()}

Rewrites eligible URLs in a rendered payload through the configured provider.