DripDrop.StartupCheck (DripDrop v0.1.0)

Copy Markdown View Source

Validates host configuration before DripDrop starts dispatching messages.

Summary

Functions

Validates optional dependencies and runtime configuration needed by DripDrop.

Types

error()

@type error() ::
  {:missing_optional_dependency, atom(), atom()}
  | {:invalid_encryption_key, term()}
  | {:invalid_scheduler, module()}
  | :unsubscribe_url_builder_unconfigured
  | {:pgflow_job_not_registered, module()}

Functions

run()

@spec run() :: :ok | {:error, [error()]}

Validates optional dependencies and runtime configuration needed by DripDrop.