DripDrop.Step (DripDrop v0.1.0)

Copy Markdown View Source

A sequence step with channel, timing, and template configuration.

Summary

Functions

Builds a changeset for sequence steps and embedded timing.

Functions

changeset(step, attrs)

@spec changeset(Ecto.Schema.t(), map()) :: Ecto.Changeset.t()

Builds a changeset for sequence steps and embedded timing.