DripDrop.Web.WebhookPlug (DripDrop v0.1.0)

Copy Markdown View Source

Framework-neutral Plug for provider webhook ingestion.

This plug resolves the provider and adapter from the mounted path, verifies the provider signature, and leaves event normalization/persistence to the event-ingestion layer.

Summary

Functions

Verifies and ingests a provider webhook request.

Initializes the webhook plug options.

Functions

call(conn, opts)

@spec call(
  Plug.Conn.t(),
  keyword()
) :: Plug.Conn.t()

Verifies and ingests a provider webhook request.

init(opts)

@spec init(keyword()) :: keyword()

Initializes the webhook plug options.