Behaviour for scheduling DripDrop step executions.
Summary
Functions
Returns the configured scheduler module.
Returns the short name (e.g. "pgflow", "oban") for the configured scheduler.
Used to populate step_executions.scheduler_backend so a later cancel/replay
routes to the correct backend even if the configured scheduler has been swapped.
Resolves a stored scheduler-backend name to its module.
Callbacks
Functions
@spec configured() :: module()
Returns the configured scheduler module.
@spec configured_name() :: binary()
Returns the short name (e.g. "pgflow", "oban") for the configured scheduler.
Used to populate step_executions.scheduler_backend so a later cancel/replay
routes to the correct backend even if the configured scheduler has been swapped.
Resolves a stored scheduler-backend name to its module.