Validates host configuration before DripDrop starts dispatching messages.
Summary
Types
Functions
@spec run() :: :ok | {:error, [error()]}
Validates optional dependencies and runtime configuration needed by DripDrop.
Validates host configuration before DripDrop starts dispatching messages.
@spec run() :: :ok | {:error, [error()]}
Validates optional dependencies and runtime configuration needed by DripDrop.