Public template helpers.
Summary
Functions
Renders a template with variables for the given channel.
Renders the template configured on a step.
Validates Liquid and channel-specific template requirements.
Public template helpers.
Renders a template with variables for the given channel.
Renders the template configured on a step.
Validates Liquid and channel-specific template requirements.