Framework-neutral Plug for provider webhook ingestion.
This plug resolves the provider and adapter from the mounted path, verifies the provider signature, and leaves event normalization/persistence to the event-ingestion layer.
Summary
Functions
@spec call( Plug.Conn.t(), keyword() ) :: Plug.Conn.t()
Verifies and ingests a provider webhook request.
Initializes the webhook plug options.